aboutsummaryrefslogtreecommitdiffstats
path: root/erts/emulator/pcre/pcre_version.c
diff options
context:
space:
mode:
authorPatrik Nyblom <[email protected]>2013-07-15 11:08:18 +0200
committerPatrik Nyblom <[email protected]>2013-07-19 18:06:02 +0200
commitd0898734b7ae62572579a0ecd0b03ab451b233bb (patch)
tree48fd4a2aef87accf9d3c12d3a0c2c411f7f8f150 /erts/emulator/pcre/pcre_version.c
parent712f2cad96a941d68a2f9ad092badd5bc60e8cdd (diff)
downloadotp-d0898734b7ae62572579a0ecd0b03ab451b233bb.tar.gz
otp-d0898734b7ae62572579a0ecd0b03ab451b233bb.tar.bz2
otp-d0898734b7ae62572579a0ecd0b03ab451b233bb.zip
Update to PCRE 8.33, w/o the erts_ prefix added
Diffstat (limited to 'erts/emulator/pcre/pcre_version.c')
-rw-r--r--erts/emulator/pcre/pcre_version.c16
1 files changed, 12 insertions, 4 deletions
diff --git a/erts/emulator/pcre/pcre_version.c b/erts/emulator/pcre/pcre_version.c
index b8a5b555ef..f771b3e82b 100644
--- a/erts/emulator/pcre/pcre_version.c
+++ b/erts/emulator/pcre/pcre_version.c
@@ -6,7 +6,7 @@
and semantics are as close as possible to those of the Perl 5 language.
Written by Philip Hazel
- Copyright (c) 1997-2008 University of Cambridge
+ Copyright (c) 1997-2012 University of Cambridge
-----------------------------------------------------------------------------
Redistribution and use in source and binary forms, with or without
@@ -38,7 +38,7 @@ POSSIBILITY OF SUCH DAMAGE.
*/
/* This module contains the external function erts_pcre_version(), which returns a
string that identifies the PCRE version that is in use. */
/* %ExternalCopyright% */
@@ -80,8 +80,16 @@ I could find no way of detecting that a macro is defined as an empty string at
pre-processor time. This hack uses a standard trick for avoiding calling
the STRING macro with an empty argument when doing the test. */
-PCRE_EXP_DEFN const char *
-erts_pcre_version(void)
+#if defined COMPILE_PCRE8
+PCRE_EXP_DEFN const char * PCRE_CALL_CONVENTION
+pcre_version(void)
+#elif defined COMPILE_PCRE16
+PCRE_EXP_DEFN const char * PCRE_CALL_CONVENTION
+pcre16_version(void)
+#elif defined COMPILE_PCRE32
+PCRE_EXP_DEFN const char * PCRE_CALL_CONVENTION
+pcre32_version(void)
+#endif
{
return (XSTRING(Z PCRE_PRERELEASE)[1] == 0)?
XSTRING(PCRE_MAJOR.PCRE_MINOR PCRE_DATE) :
@@ -38,7 +38,7 @@ POSSIBILITY OF SUCH DAMAGE.
*/
-/* This module contains the external function erts_pcre_version(), which returns a
+/* This module contains the external function pcre_version(), which returns a
string that identifies the PCRE version that is in use. */
/* %ExternalCopyright% */